@@ -1,9 +1,9 @@
 package Time::Elapsed::Lang::EN;
 use strict;
 use utf8;
-use vars qw($VERSION);
+use vars qw( $VERSION );
 
-$VERSION = '0.12';
+$VERSION = '0.13';
 
 sub singular {
    qw/
@@ -28,9 +28,11 @@ sub plural {
 }
 
 sub other {
-   and     => q{and},
-   ago     => q{ago},
-   zero    => q{zero seconds},
+   qw/
+   and     and
+   ago     ago
+   /,
+   zero => q{zero seconds},
 }
 
 1;
